@@ -22,6 +22,16 @@ NumericVector cpp_dmixnorm(
     const bool& log_prob = false
   ) {
   
+  if (std::min({static_cast<int>(x.length()),
+                static_cast<int>(mu.nrow()),
+                static_cast<int>(mu.ncol()),
+                static_cast<int>(sigma.nrow()),
+                static_cast<int>(sigma.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(mu.nrow()),
@@ -89,6 +99,16 @@ NumericVector cpp_pmixnorm(
     const bool& log_prob = false
   ) {
   
+  if (std::min({static_cast<int>(x.length()),
+                static_cast<int>(mu.nrow()),
+                static_cast<int>(mu.ncol()),
+                static_cast<int>(sigma.nrow()),
+                static_cast<int>(sigma.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(mu.nrow()),
@@ -159,6 +179,16 @@ NumericVector cpp_rmixnorm(
     const NumericMatrix& alpha
   ) {
   
+  if (std::min({static_cast<int>(mu.nrow()),
+                static_cast<int>(mu.ncol()),
+                static_cast<int>(sigma.nrow()),
+                static_cast<int>(sigma.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   int k = alpha.ncol();
   NumericVector x(n);
   
