@@ -55,6 +55,10 @@ NumericVector cpp_qtlambda(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), lambda.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     lambda.length()
@@ -87,6 +91,11 @@ NumericVector cpp_rtlambda(
     const NumericVector& lambda
   ) {
   
+  if (lambda.length() < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
